#
# spec file for package terragrunt
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           terragrunt
Version:        0.78.1
Release:        1.1
Summary:        Thin wrapper for Terraform for working with multiple Terraform modules
License:        MIT
URL:            https://github.com/gruntwork-io/terragrunt
Source:         terragrunt-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        Makefile
Source3:        PACKAGING_README.md
BuildRequires:  go1.23

%description
Terragrunt is a thin wrapper for Terraform that provides extra tools for
keeping your Terraform configurations DRY, working with multiple Terraform
modules, and managing remote state.

%prep
%autosetup -p1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X github.com/gruntwork-io/go-commons/version.Version=v%{version}"

%install
# Install the binary.
install -D -m 0755 %{name} %{buildroot}/%{_bindir}/%{name}

%files
%doc README.md
%license LICENSE.txt
%{_bindir}/%{name}

%changelog
* Tue May  6 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.78.1:
  * fix: AWS S3 backend access logging bucket not versioning
    (#4246)
  * docs: Updating docs now that stacks are generally available
    (#4243)
* Fri May  2 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.78.0:
  * Experiments Completed
    The stacks experiment is now complete.
    If you were previously using the flag --experiment stacks to
    opt in to experimental functionality, you no longer have to do
    so. Note that if you are, you will simply get a warning that it
    is no longer necessary.
  * Breaking Changes
    Legacy commands (as replaced by the CLI Redesign are now
    deprecated, and will be phased out at a future date, which will
    be scheduled in #3535. Make sure to subscribe to the issue if
    you would like to be informed when these deprecated features
    are no longer supported.
    For instructions on migrating to the new commands provided
    after the CLI Redesign, read the CLI Redesign Migration Guide.
    The following are now deprecated:
  - hclfmt (use hcl fmt instead)
  - hclvalidate (use hcl validate instead)
  - validate-inputs (use hcl validate --inputs and hcl validate
  - -inputs --strict instead)
  - terragrunt-info (use info print instead)
  - output-module-groups (use find --dag --json instead)
  - render-json (use render --json -w instead)
  - graph-dependencies (use dag graph instead)
  - run-all (use run --all instead)
  - graph (use run --graph instead)
  - The default command. e.g. terragrunt workspace list (use
    terragrunt run -- workspace list instead)
  - Default bootstrap (automatically provisioning backend
    resources without additional flags). This is now opt in
    behavior, and requires usage of the --backend-bootstrap flag
    or explicitly running the new backend bootstrap command.
  - aws-provider-patch (we are simply deprecating this command,
    and removing it when the other commands are removed. It
    served its purpose as a short term stopgap tool).
    Note that this will not result in an immediate breaking change
    for users, as we’ll have an initial deprecation window to give
    users time to adjust to these changes. If you’d like to ensure
    that you are prepared for the future removal of legacy
    commands, you can take advantage of the cli-redesign strict
    control to opt in to the future breaking change early.
  * Enhancements
    The logging for stack generation has been improved to make it
    easier to determine at a glance the stack file that’s
    generating a particular unit.
  * What's Changed
  - feat: improved stack logs generation by @denis256 in #4213
  - feat: stacks expriment completion by @denis256 in #4222
  - feat: Deprecating render-json command by @levkohimins in
    [#4227]
  - feat: Deprecating aws-provider-patch command by @levkohimins
    in #4228
  - feat: Deprecating output-module-groups command by
    @levkohimins in #4229
  - fix: Fixing base tests for macOS by @yhakbar in #4193
  - fix: Fixing 404 in performance docs by @yhakbar in #4194
  - fix: basic tests execution update by @denis256 in #4192
  - fix: Throwing interrupt signal with --all flag by
    @levkohimins in #4224
  - fix: handling of errors in parsing base blocks by @denis256
    in #4226
  - fix: Cleaning up legacy -all usage by @yhakbar in #4239
  - fix: Rename all the --terragrunt- flags by @yhakbar in #4203
  - fix: Cleaning up run-all usage by @yhakbar in #4223
  - fix: Updating environment variables for flags by @yhakbar in
    [#4240]
  - fix: Updating migration guide for CLI Redesign migration by
    @yhakbar in #4207
  - docs: Adding docs for cli-redesign strict control by @yhakbar
    in #4238
  - docs: Documenting CLI Redesign deprecations by @yhakbar in
    [#4237]
  - docs: updated stack links by @denis256 in #4201
  - chore: Preserve tests with deprecated commands/flags by
    @levkohimins in #4242
  - chore: hclfmt hclvalidate validate-inputs as deprecated
    commands (minor fixes) by @levkohimins in #4199
  - chore: hclfmt hclvalidate validate-inputs as deprecated
    commands by @levkohimins in #4196
  - build(deps): bump github.com/getsops/sops/v3 from 3.10.1 to
    3.10.2 by @dependabot in #4185
  - build(deps): bump
    go.opentelemetry.io/otel/exporters/stdout/stdouttrace from
    1.34.0 to 1.35.0 by @dependabot in #4184
  - build(deps): bump DavidAnson/markdownlint-cli2-action from 15
    to 19 by @dependabot in #4187
  - build(deps): bump ruby/setup-ruby from 1.230.0 to 1.233.0 by
    @dependabot in #4186
  - build(deps-dev): bump nokogiri from 1.18.4 to 1.18.8 in /docs
    by @dependabot in #4195
* Fri Apr 25 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.77.22:
  * Experiments Completed
    The cli-redesign experiment is now complete.
    If you were previously using the flag --experiment cli-redesign
    to opt in to experimental functionality, you no longer have to
    do so. Note that if you are, you will simply get a warning that
    it is no longer necessary.
  * What's Changed
  - chore: Complete CLI Redesign experiment (#4189)
  - feat: Adding base tests (#4176)
* Thu Apr 24 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.77.21:
  * New Features
  - Introduction of hcl commands
    As part of the CLI Redesign experiment, the hcl commands have
    been introduced.
    The hcl commands allow users to directly interact with HCL
    content independent of the underlying functionality they
    support.
    The functionality of the hcl commands replace existing
    functionality that is soon to be deprecated:
    hclfmt --> hcl fmt
    hclvalidate --> hcl validate
    validate-inputs --> hcl validate --inputs
    validate-inputs --strict-validate --> hcl validate --inputs --strict
  * What's Changed
  - fix: Update status of cli-redesign experiment (#4188)
  - feat: `hcl` commands docs (#4180)
  - fix: Fix spelling (#4179)
  - feat: Implementation of `hcl` commands (#4169)
  - feat: add symbol link experiemnt in discovery process (#4177)
  - fix: Adding redirect from /docs/reference/experiment-mode to
    /docs/reference/experiments (#4178)
  - build(deps): bump github.com/charmbracelet/bubbles from
    0.20.0 to 0.21.0 (#4160)
* Fri Apr 18 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.77.20:
  * build(deps): bump github.com/aws/aws-sdk-go-v2/service/s3
    (#4158)
  * build(deps): bump golang.org/x/term from 0.30.0 to 0.31.0
    (#4159)
  * build(deps): bump github.com/ProtonMail/go-crypto from 1.1.6 to
    1.2.0 (#4161)
  * feat: Adding markdownlint v2 to GitHub Actions workflows
    (#4175)
  * feat: Adding codespell workflow (#4173)
  * feat: Adding `lint.yml` and `strict-lint.yml` workflows for
    GitHub Actions (#4172)
  * fix: Improving getting started guide (#4174)
  * feat: Adding `build-no-proxy.yml` workflow (#4171)
* Fri Apr 18 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.77.19:
  * New Features
  - OpenTelemetry traces are now integrated into find and list
    commands
    Please see the release for example screenshots
    https://github.com/gruntwork-io/terragrunt/releases/tag/v0.77.19
  * What's Changed
  - feat: add telemetry for find/list (#4165)
* Fri Apr 18 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.77.18:
  * New Features
  - Support for HCL formatting with the render command
    As part of the CLI Redesign experiment, the render command
    now supports HCL formatting for rendered configurations,
    which is the default output format.
    Using the render command with HCL formatting allows users to
    get a quick, minimal evaluation of Terragrunt unit
    configurations with as much pre-processing done as possible.
    Using the render command with HCL formatting offers a way to
    resolve complex HCL function evaluation, include merging or
    string interpolation, etc. to achieve equivalent Terragrunt
    HCL configurations that are easier to reason about.
  * What's Changed
  - feat: Adding `render` with HCL formatting (#4164)
* Wed Apr 16 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.77.17:
  * New Features
  - Introduction of the render command
    As part of the CLI Redesign experiment, the render command
    has been introduced.
    The render command allows users to easily render Terragrunt
    unit configurations with reduced complexity, making it easier
    to understand configurations at a glance.
    The introduction of the render command is part of the
    eventual deprecation of the existing render-json command,
    which will be deprecated by the end of the CLI Redesign. The
    render command is a higher level command, that offers the
    ability to write to stdout, in addition to writing to files,
    and will support HCL configurations in addition to JSON
    (coming soon).
    To learn more about the render command, read the official
    documentation here.
    https://terragrunt.gruntwork.io/docs/reference/cli-options/#render
  * What's Changed
  - feat: Adding docs for `backend migrate` (#4140)
  - feat: Adding `render` command (#4145)
  - build(deps): bump ruby/setup-ruby from 1.229.0 to 1.230.0 (#4162)
* Wed Apr 16 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.77.16:
  * New Features
  - Introduction of the backend migrate command
    As part of the CLI Redesign experiment, the backend migrate
    command has been introduced.
    The backend migrate command allows you to simply migrate
    state between different units (or renames of units) without
    manually running OpenTofu/Terraform state migration commands.
    To learn more about the backend migrate command, read the
    official docs.
  * What's Changed
  - feat: Improve error explainer to catch stack values errors
    (#4163)
  - feat: Support state migration between different backends
    (#4154)
  - fix: disable tf rc file overwriting for non-cached commands
    (#4155)
  - fix: Deprecated flags msg for experimental command (#4146)
* Wed Apr 16 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.77.15:
  * New Features
  - Introduction of the dag graph command
    As part of the CLI Redesign experiment, the dag graph command
    has been introduced.
  * What's Changed
  - feat: add dag graph command (#4143)
  - docs: Adding migration guide for adopting Terragrunt Stacks
    (#4152)
* Sat Apr 12 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.77.14:
  * New Features
    Support for --exclude and --queue-construct-as in find and list
    The find and list commands have been updated to leverage new
    capabilities involving greater understanding of the Terragrunt
    run queue.
    Users can now leverage the --queue-construct-as (or just --as)
    flag in the find and list commands to discover configurations
    as if a particular Terragrunt command was being run (e.g. plan,
    destroy).
    The find and list commands will now construct the Terragrunt
    run queue as if a particular command was being run, potentially
    altering the position of elements in the run queue, based on
    their dependencies (dependencies before dependents for plans,
    applies, etc. and dependents before dependencies for destroys).
    In addition, users can leverage the --exclude flag on the find
    command to get information on the exclude block included in
    results. The exclude block is also factored in to discovery
    results when the --queue-construct-as flag is passed, allowing
    users to dry-run behavior of the exclude block before
    performing any Terragrunt runs.
  * What's Changed
  - feat: Adding exclude support to list and find (#4147)
* Fri Apr 11 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.77.13:
  * build(deps): bump github.com/getsops/sops/v3 from 3.9.4 to
    3.10.1 (#4130)
  * build(deps): bump golang.org/x/oauth2 from 0.28.0 to 0.29.0
    (#4131)
  * build(deps): bump golang.org/x/sys from 0.31.0 to 0.32.0
    (#4133)
  * build(deps): bump google.golang.org/grpc from 1.71.0 to 1.71.1
    (#4132)
* Fri Apr 11 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.77.12:
  * New Features
    Introduced no_validation attribute for stack and unit, allowing
    users to bypass Terragrunt's validation checks when deploying
    infrastructure. This is particularly useful in scenarios where
    you need to deploy infrastructure that doesn't strictly adhere
    to Terragrunt's validation rules, such as during emergency
    deployments or when working with legacy infrastructure
    patterns.
  * What's Changed
  - feat: add support for no_validation attribute for stack and
    unit (#4149)
  - feat: Adding a bit more docs for stacks (#4144)
* Wed Apr  9 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.77.11:
  * New Features
    Introduction of the info print command
    As part of the CLI Redesign experiment, the info print command
    has been introduced.
  * What's changed
  - feat: add info command (#4122)
* Wed Apr  9 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.77.10:
  * fix: Back out migrate command pending resolution (#4142)
  * fix: Fixing optional default template (#4141)
  * feat: Implementation `backend migrate` command (#4135)
  * feat: stack code improvements (#4136)
  * fix: remove warning message for unimplemented backends (#4138)
  * fix: Suppressing warning for catalog when determining default
    file name (#4134)
* Tue Apr  8 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.77.9:
  * Bug fixes
    Fetching Outputs from Nested Stacks
    Resolved an issue that prevented the correct retrieval of
    outputs from nested stacks.
  * What's Changed
  - fix: corrected the logic for fetching outputs from nested
    stacks by @denis256 in #4126
* Tue Apr  8 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.77.8:
  * Documentation Updates
    A new performance guide has been added to Terragrunt
    documentation to offer guidance on how performance can be
    improved when using Terragrunt or contributing to the
    Terragrunt codebase.
    https://terragrunt.gruntwork.io/docs/troubleshooting/performance/
    This documentation will evolve over time, as more optional
    optimizations become available, or are no longer necessary, as
    they become default behavior.
  * What's Changed
  - feat: Add performance guide by @yhakbar in #4120
  - build(deps): bump ruby/setup-ruby from 1.221.0 to 1.229.0 by
    @dependabot in #4100
  - fix: Addressing commas in external IDs by @yhakbar in #4128
* Thu Apr  3 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.77.7:
  * New Features
    Users can now configure a custom default template for scaffold
    and catalog commands in their catalog configuration blocks like
    so:
    catalog {
    default_template = "git@github.com/acme/example.git//path/to/template"
    }
    For more information, read the documentation in the catalog
    feature.
  * What's Changed
  - fix: Updating docs after #4035 (#4117)
  - feat: Adding custom default template (#3658) (#4035)
  - feat: stacks improvements (#4114)
* Wed Apr  2 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.77.6:
  * bug: added limitation on detection of stack files (#4113)
  * fix: Ignoring lock table encryption setting (#4112)
  * feat: added support for parsing stack config from string
    (#4110)
* Tue Apr  1 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.77.5:
  * feat: added support for OpenTelemetry in stack commands to
    enable enhanced observability and tracing by @denis256 in #4109
* Tue Apr  1 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.77.4:
  * Bug fixes
  - Newlines reduced in Error Logging for Configuration Errors
    Logging for configuration errors has been compacted to reduce
    noise, and make errors easier to read.
  - Improved Cycle Detection Logic for stack generate
    On the default filesystem for macOS, path length was likely
    to result in an error before internal cycle detection logic,
    so cycle detection was updated to leverage a maximum path
    length of 1024 characters as an earlier exit for all
    operating systems.
  - Excessive warning for bootstrap requirement resolved
    Internal logic for determination that backends required
    bootstrapping was adjusted to no longer leverage the value of
    the OpenTofu state file.
    While cheaper than making a network request to assess the
    current state of backend resources, it also resulted in false
    negatives, which triggered excessive backend bootstrap
    warnings.
  * What's Changed
  - fix: New lines in TF diagnostic log by @levkohimins in #4108
  - fix: Stack cycles detection improvements by @denis256 in
    [#4106]
  - fix: Fixing excessive warning for bootstrap by @yhakbar in
    [#4107]
* Mon Mar 31 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.77.3:
  * Enhancements
    Error Handling for Discovery
    The find and list commands now leverage improved error handling
    when discovering configurations throughout Terragrunt projects.
    When configurations require authentication due to usage of
    functionality like get_aws_account_id(), have errors in their
    configurations or cycles between dependencies, the commands
    will do their best to return valid results, and warn the user
    that the results are incomplete due to suppressed errors or cut
    cycles.
    This should allow for usage of the find and list commands in
    more real-world use-cases, which frequently require this kind
    of error handling.
  * What's Changed
  - feat: Adding error handling for discovery by @yhakbar in
    [#4098]
* Mon Mar 31 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.77.2:
  * New Features
    The backend configuration block now supports
    assume_role_with_web_identity for configuring the backend block
    of the OpenTofu/Terraform terraform block.
    This allows users separately authenticating to backends with a
    different role to leverage role assumption with OIDC.
    For more information, see the backend docs.
  * What's Changed
  - feat: Adding assume_role_with_web_identity for backend
    configs by @yhakbar in #4097
  - chore: simplified processing of errors block by @denis256 in
    [#4046]
  - build(deps): Updated google.golang.org/protobuf to 1.36.6 by
    @denis256 in #4096
  - build(deps): Updated github.com/charmbracelet/lipgloss to
    v1.1.0 by @denis256 in #4096
  - build(deps): Update
    github.com/gruntwork-io/terragrunt-engine-go to v0.0.13 by
    @denis256 in #4096
  - build(deps): Update github.com/urfave/cli/v2 to v2.27.6 by
    @denis256 in #4096
* Fri Mar 28 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.77.1:
  * New Features
  - Improved error handling by adding a test check for
    non-existent stack and unit paths, ensuring clearer messages
    when expected files are missing.
  * What's Changed
  - feat: added support for reading stack configuration and
    values files by @denis256 in #4085
  - feat: enhanced stack validation with improved checks and
    error reporting by @denis256 in #4078
* Fri Mar 28 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.77.0:
  * Breaking Changes
  - Best Effort Parsing
    Exported functions like ParseConfig and ParseConfigString now
    perform best effort parsing instead of early returns.
    Consumers of Terragrunt as a library should be aware of this
    change, as it can result in partially parsed configurations
    being returned instead of nil when errors are encountered
    during parsing. As a consumer of these functions, you are
    responsible for checking the errors being returned, and
    handling the returned configuration value accordingly.
    These changes are being introduced to support greater parsing
    flexibility for usage in the find and list command, which
    will be able to handle partial parse failures while still
    returning valuable information, along with the Terragrunt
    LSP, which needs the same adjustments to parsing.
  - Struct Field Alignment
    The fieldalignment govet lint has been introduced to the
    codebase, and all structs that had less efficient struct
    field alignment have been updated to minimize their memory
    footprint. If you are consuming Terragrunt as a library, you
    may have to make changes to how you are leveraging exported
    structs from Terragrunt.
    The simplest way to avoid any breakage related to this change
    is to avoid usage of unkeyed composite literals.
    See the release for details:
    https://github.com/gruntwork-io/terragrunt/releases/tag/v0.77.0
  - Telemetry Environment Variable Name Changes
    The following environment variables now have new aliases:
  - TERRAGRUNT_TELEMETRY_TRACE_EXPORTER --> TG_TELEMETRY_TRACE_EXPORTER
  - TERRAGRUNT_TELEMETRY_TRACE_EXPORTER_HTTP_ENDPOINT --> TG_TELEMETRY_TRACE_EXPORTER_HTTP_ENDPOINT
  - TERRAGRUNT_TELEMETRY_TRACE_EXPORTER_INSECURE_ENDPOINT --> TG_TELEMETRY_TRACE_EXPORTER_INSECURE_ENDPOINT
  - TERRAGRUNT_TELEMETRY_METRIC_EXPORTER --> TG_TELEMETRY_METRIC_EXPORTER
  - TERRAGRUNT_TELEMETRY_METRIC_EXPORTER_INSECURE_ENDPOINT --> TG_TELEMETRY_METRIC_EXPORTER_INSECURE_ENDPOINT
    These environment variables have been renamed to align more
    closely with the rest of the changes in the CLI Redesign.
    Note that the TRACEPARENT environment variable has not
    changed. This environment variable is semi-standard in the
    OpenTelemetry space, so we've preserved it.
    This is not a breaking change with this release, but will be
    in the future. As with all the environment variable renames
    that have taken place during the CLI Redesign, both the
    legacy environment variable and the new environment variable
    will be supported to give users time to make requisite
    adjustments. If you would like to opt in to stricter behavior
    that requires usage of the new environment variables,
    leverage the terragrunt-prefix-env-vars strict control.
  * New Features
  - Introduction of backend bootstrap and backend delete
    This release introduces two new commands named backend
    bootstrap and backend delete.
    These commands allow for manual control over the process by
    which Terragrunt can manage backend state resources on behalf
    of users.
  - backend bootstrap
    The backend bootstrap command allows users to explicitly
    bootstrap resources like S3 buckets, GCS buckets, DynamoDB
    tables, etc. used to manage state for OpenTofu/Terraform.
    It is accompanied by a flag (--backend-bootstrap) which
    explicitly enables this behavior by default before performing
    any operation that might require backend resources (like the
    run command).
    The introduction of this command is part of the future
    deprecation of provisioning backend resources by default when
    using Terragrunt. You can learn more about this in the CLI
    Redesign.
  - backend delete
    The backend delete command allows users to delete state
    resources relevant to one or more units in remote state.
    Terragrunt performs two safety checks to mitigate the risk of
    accidentally removing the wrong backend state resource:
    1. By default, Terragrunt will refuse to remove any backend
    state file if versioning is not enabled for the backend S3
    bucket or GCS bucket. To explicitly ignore this safety
    check, users must provide the --force flag.
    2. By default, Terragrunt will prompt users to confirm their
    decision to remove a given backend state file. To
    explicitly ignore this safety check, users must provide
    the --non-interactive flag.
    The introduction of this command is part of a larger effort
    to provide users greater control over the full lifecycle of
    backend state resources by Terragrunt. You can learn more
    about this in the CLI Redesign.
  * What's Changed
  - feat: Adding best effort parsing by @yhakbar in #4044
  - feat: Implementation of backend commands: bootstrap, delete
    by @levkohimins in #4070
  - feat: Backend delete prompt by @levkohimins in #4091
  - feat: Adding backend docs by @yhakbar in #4087
  - fix: Updating homepage title by @yhakbar in #4081
  - fix: Addressing stricter lint findings by @yhakbar in #4090
  - fix: Fixing visible flags by @yhakbar in #4088
  - fix: Renaming telemetry envs prefix TERRAGRUNT_ with TG_ by
    @levkohimins in #4084
  - fix: Fixing backend delete safety features by @yhakbar in
    [#4089]
  - fix: Avoiding duplicate description in flag names by @yhakbar
    in #4092
  - fix: terraform_binary with run version command by
    @levkohimins in #4095
  - build(deps-dev): bump nokogiri from 1.18.3 to 1.18.4 in /docs
    by @dependabot in #4069
* Tue Mar 25 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.76.8:
  * New Features
    OpenTofu file extension detection
    OpenTofu-specific file extensions (*.tofu and *.tofu.json) are
    detected by default, just like generic *.tf, *.tf.json files,
    which are used by both OpenTofu and Terraform.
    This ensures that future incompatibility between OpenTofu and
    Terraform which specifically requires usage of the *.tofu file
    extension will be supported without additional effort.
    Thank you to @wazy for contributing this new feature.
  * What's Changed
  - Support *.tofu and .*tofu.json file detection by @wazy in
    [#4062]
* Mon Mar 24 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.76.7:
  * build(deps): bump github.com/golang-jwt/jwt/v5 from 5.2.1 to
    5.2.2 (#4066)
* Sat Mar 22 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.76.6:
  * feat: add error throwing in case of absolut path for stack
    (#4055)
  * feat: Adding `govet` alignment check (#4057)
* Fri Mar 21 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.76.5:
  * fix(docs): Addressing some missed renames of terragrunt.hcl to
    root.hcl in the docs by @yhakbar in #4058
  * build(deps): Updated cloud.google.com/go/storage to 1.51.0 by
    @denis256 in #4059
  * build(deps): Updated
    go.opentelemetry.io/otel/exporters/stdout/stdoutmetric to
    1.35.0 by @denis256 in #4059
  * build(deps): Updated
    go.opentelemetry.io/otel/exporters/otlp/otlptrace/otlptracehttp
    to 1.35.0 by @denis256 in #4059
  * build(deps): Updated golang.org/x/oauth2 to 0.28.0 by @denis256
    in #4059
  * build(deps): Updated
    go.opentelemetry.io/otel/exporters/otlp/otlpmetric/otlpmetrichttp
    to 1.35.0 by @denis256 in #4059
* Fri Mar 21 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.76.4:
  * feat: Introduced -a alias for the -all flag #4048 by
    @levkohimins
  * feat: Implemented detection of nested stacks #4052 by @denis256
  * fix: Refactored list package structure #4050 by @yhakbar
  * fix: Updated documentation for list usage #4051 by @yhakbar
  * fix: Corrected .stack references in generated documentation
    [#4053] by @yhakbar
* Thu Mar 20 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.76.3:
  * Breaking Changes
  - find --sort=dag changed to find --dag
    The experimental find command no longer has a --sort flag.
    Instead the ability to sort configurations according to their
    position in the DAG has been replaced with the dedicated
  - -dag flag, which puts the command in "DAG Mode". These
    changes have been done to allow for closer parity in the
    behavior of find and list.
    [#] Before
    terragrunt find --sort=dag
    [#] After
    terragrunt find --dag
  * New Features
  - Introduction of the list command
    As part of the CLI Redesign experiment, the list command has
    been introduced. As with other new features, usage requires
    enabling the CLI Redesign experiment.
    The list command helps you discover and display Terragrunt
    configurations in your codebase. It provides various output
    formats and options to help you understand the structure and
    dependencies of your Terragrunt configurations.
    The list command is very similar to the find command. It uses
    the same backend logic for configuration discovery. It also
    supports very similar flags and configuration options.
    Generally, the list command is optimized for displaying
    configurations in a format that is easy for a human to read
    and understand, so there are more configuration options, and
    the output is more verbose. Output from the list command can
    vary significantly depending on the flags used, and the
    output structure is more variable than that of the find
    command.
    Use the list command when you want to visualize your
    Terragrunt configurations in a human-readable format. Use the
    find command when you want to programmatically search for
    configurations in your codebase.
    Usage
    Please see the description and screenshots in the release:
    https://github.com/gruntwork-io/terragrunt/releases/tag/v0.76.3
  * What's Changed
  - feat: Adding `list` command (#4034)
* Thu Mar 20 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.76.2:
  * New Features
  - Added --no-stack-generate support in stack run and stack
    output, allowing users to disable automatic stack
    regeneration before executing commands. This provides greater
    control over execution by enabling operations to run using
    the existing .terragrunt-stack directory, improving
    efficiency and avoiding unnecessary updates.
  * What's Changed
  - feat: Added --no-stack-generate cli flag to skip stack
    generation by @denis256 in #4039
  - chroe: Stack tests improvements by @denis256 in #4033
  - chrore: Adding .cursor to .gitignore by @yhakbar in #4040
  - docs: Adding docs for --all and --graph by @yhakbar in #4036
  - docs: Move info to a better location by @yhakbar in #4037
* Mon Mar 17 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.76.1:
  * New Features
    Introduced no_dot_terragrunt_stack support in stack and unit,
    allowing users to opt out of generating .terragrunt-stack
    directories. This enables seamless adoption of
    terragrunt.stack.hcl without requiring state migration for
    existing infrastructure.
  * What's Changed
  - Stacks: add support for no_dot_terragrunt_stack (#4019)
* Mon Mar 17 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.76.0:
  * New Features / Breaking Changes
  - Catalog/Scaffold no longer requires --root-file-name root.hcl
    The catalog and scaffold commands will now attempt to
    discover a parent root.hcl file by default and use it as the
    default root Terragrunt configuration when present to help
    users adopt the changes in
    migrating-from-root-terragrunt-hcl.
    Users that have switched over to use root.hcl as the root of
    their Terragrunt configurations instead of terragrunt.hcl
    will no longer need to explicitly pass --root-file-name
    root.hcl or use the root-terragrunt-hcl strict control to
    automatically discover the root of their Terragrunt
    configurations when using catalog or scaffold.
    Note that this is technically a breaking change to the way
    that catalog and scaffold work. With this change, users that
    have both a root.hcl file and a terragrunt.hcl file at the
    root of their repositories will have the root.hcl file used
    instead of the terragrunt.hcl file for the catalog and
    scaffold commands.
    If you are not yet ready to rename the terragrunt.hcl file at
    the root of your repository, use the --root-file-name flag to
    explicitly provide terragrunt.hcl as the name of the
    Terragrunt configuration at the root of your Terragrunt
    project.
    This change was made as most users are very unlikely to have
    both root.hcl (the recommended root of Terragrunt
    configurations) and terragrunt.hcl (the legacy root of
    Terragrunt configurations in the same Terragrunt project) at
    the root of their Terragrunt project. This configuration is
    entirely CLI based, making it relatively easy to address for
    users (as opposed to HCL configurations, which might take
    more time for teams to address).
    Users looking to move from a root terragrunt.hcl file to a
    root.hcl file will still need to read through the migration
    guide to adjust all usages of find_in_parent_folders when
    making the switch.
  * What's Changed
  - fix: Lookup root.hcl if present by @yhakbar in #4022
  - fix: Improving logic for scaffold default root discovery by
    @yhakbar in #4029
  - fix: Fixing configuration parsing order link by @yhakbar in
    [#4021]
* Fri Mar 14 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.75.10:
  * Dependencies update (#4020)
  * fix: Addressing `gopls` findings (#4018)
  * build(deps): bump golang.org/x/net from 0.35.0 to 0.36.0
    (#4013)
* Thu Mar 13 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.75.9:
  * Bug fixes
  - Using absolute paths for mark_as_read
    The internal store for the values mark_as_read was tracking
    now use absolute paths instead of "canonical paths". The
    result of this is that even if you are using tooling like
    run_cmd to dynamically discover files to mark as read, you
    should still expect --queue-include-units-reading to work
    correctly.
  * What's Changed
  - fix: Use abs path for mark_as_read by @yhakbar in #4015
* Thu Mar 13 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.75.8:
  * Stacks: usage of source-map for sources (#4011)
* Thu Mar 13 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.75.7:
  * New Features
  - find supports dag sorting
    The find command now supports the ability to sort results by
    their relative positions in the Directed Acyclic Graph (DAG).
    To use the find command, you must enable the cli-redesign
    experiment.
  - The stack run command now supports all run flags
    The stack run command now supports all the same flags run
    supports, including --queue-include-dir.
    To use stack commands, you must enable the stacks experiment.
    As an example of what's supported now:
    terragrunt --experiment stacks stack run apply --queue-strict-include --queue-include-dir=./.terragrunt-stack/app1 --non-interactive
    More information can be found in the stack run docs.
    https://terragrunt.gruntwork.io/docs/reference/cli-options/#stack-run
  * What's Changed
  - feat: Adding DAG support to find (#4001)
  - Stacks: run cli arguments (#4005)
  - fix: Reducing noise for skipped dependency inputs (#4007)
  - fix: Upgrading `golangci-lint` (#3987)
* Wed Mar 12 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.75.6:
  * Stacks: parallel stacks generation (#3999)
  * Addressing #3974 feedback (#4002)
  * feat: add engine support to dependencies (#3974)
* Tue Mar 11 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.75.5:
  * New Features
    This release introduces experimental support for the Terragrunt
    Content Addressable Store (CAS).
    To enable this feature, you must use the cas experiment.
    When using the CAS, the catalog command will store its contents
    in a CAS to deduplicate repository contents, then construct the
    resultant repo from the CAS.
    You can use Git URLs for the catalog command normally, and when
    the cas experiment is enabled, Terragrunt will leverage the CAS
    to save you clone time and disk space:
    catalog {
    urls = [
    "git@github.com:acme/modules.git"
    ]
    }
    There are more planned integration points for the CAS, but for
    now only the catalog command is supported.
    You can learn more about the CAS in the feature documentation.
    https://terragrunt.gruntwork.io/docs/features/cas/
  * feat: Adding cas support to catalog (#3929)
  * feat: Adding integration testing to the `find` command. (#3997)
  * Engine tests improvements (#3995)
* Mon Mar 10 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.75.4:
  * feat: Adding `find` command (#3981)
  * fix: Remove usage of template provider (#3986)
  * Fixed failing circleci jobs (#3988)
  * build(deps): bump github.com/gruntwork-io/terratest from 0.47.2
    to 0.48.2 (#3858)
  * fix: Adding docs from role assumption updates in Jekyll docs
    (#3985)
* Fri Mar  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.75.3:
  * chore: Bumping Dependencies as requested by Dependabot (#3984)
  * Add support for all assume_role block arguments for s3 backend
    (#3975)
  * fix: Adjusting contribution docs (#3979)
  * feat: update contributing.md with dev containers entry (#3977)
* Thu Mar  6 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.75.2:
  * Stacks: stack values (#3961)
* Thu Mar  6 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.75.1:
  * fix: Adding missing cautionary asides (#3970)
  * Update mark_as_read example and docs (#3971)
  * feat: Adding `.coderabbit.yaml` file (#3969)
  * feat: Strict control for old deprecated env vars (#3964)
  * build(deps-dev): bump uri from 0.13.0 to 0.13.2 in /docs
    (#3963)
  * fix: Replacing usage of `run-all` with `run --all` in starlight
    docs (#3950)
  * fix: updated failing engine tests (#3960)
  * Tofu engine update to v0.0.16 (#3951)
* Wed Mar  5 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.75.0:
  Terraform 1.11 support: We are now testing Terragrunt against
  Terraform 1.11 and is confirmed to be working.
  NOTE: Although this release is marked as backward incompatible,
  it is functionally compatible as nothing has been changed in
  Terragrunt internals. The minor version release is useful to mark
  the change in Terraform version that is being tested.
  * Add support for Terraform 1.11 (#3958)
  * fix: Using `run -- graph` command (#3959)
* Wed Mar  5 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.74.0:
  * Terraform 1.10 (#3605)
  * feat: Implementation of `--all` `--graph` flags (#3944)
* Sat Mar  1 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.73.16:
  * Stacks: nested stacks (#3900)
  * build(deps): bump github.com/go-jose/go-jose/v4 from 4.0.4 to
    4.0.5 (#3930)
  * feat: Support new pre-release process (#3941)
* Thu Feb 27 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.73.15:
  * fix: Caching the same provider with different versions from
    various sources (#3935)
* Wed Feb 26 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.73.14:
  * feat: Adding retry for clone errors (#3933)
  * fix: Fixing more gaps in the docs (#3924)
  * docs: Updating pre-release process (#3925)
* Tue Feb 25 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.73.13:
  * fix #2072 make sure the `generated` code is formatted before
    writing it to a file. (#3917)
* Mon Feb 24 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.73.12:
  * Stacks: values generation (#3914)
  * fix: More docs fixes (#3919)
- Update to version 0.73.11:
  * fix: Preventing log enrichment for bare mode (#3916)
  * fix: Adding explicit test for missing dependency (#3915)
  * build(deps): bump github.com/puzpuzpuz/xsync/v3 from 3.5.0 to
    3.5.1 (#3892)
* Fri Feb 21 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.73.10 (0.73.9 was broken):
  * fix #3824 add `if` parameter to `hook` block. (#3913)
  * feat: Adding auto-generated docs scaffold (#3876)
  * Remove unnecessary slash (#3912)
  * feat: Handling of incorrectly used flag (#3901)
  * build(deps-dev): bump nokogiri from 1.16.5 to 1.18.3 in /docs
    (#3905)
  * Updated stack output help flags (#3899)
* Wed Feb 19 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.73.8:
  * Added --output-folder flag to scaffold (#3805)
  * build(deps): bump google.golang.org/api from 0.220.0 to 0.221.0
    (#3893)
* Wed Feb 19 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.73.7:
  * Stack unit path validation (#3897)
  * feat: Clean up TF commands help (#3895)
  * build(deps): bump ruby/setup-ruby from 1.215.0 to 1.221.0
    (#3894)
  * refactor: replace `golang.org/x/exp` with stdlib (#3881)
* Sun Feb 16 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.73.6:
  * Stack: stack values (#3877)
* Sun Feb 16 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.73.5:
  * feat: added self-hosted gitlab to catalog command (#3867)
* Sun Feb 16 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.73.4:
  * Dependencies update (#3890)
* Sun Feb 16 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.73.3:
  * Unit path check improvements (#3884)
  * feat: Adding Incremental Static Regeneration to Starlight
    rewrite (#3886)
  * fix: Fixing some stacks docs (#3887)
* Fri Feb 14 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.73.2:
  * fix: Correct displaying deprecated flag warnings (#3880)
  * fix: Fixing excessive warning for dependency input usage
    (#3879)
* Wed Feb 12 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.73.1:
  * Stack: clean (#3871)
  * feat: Redesign CLI help (#3870)
  * Fix TestStacksGenerateRemote (#3865)
  * feat: Adjusting icons for Terragrunt `.hcl` configs and
    OpenTofu `.tf` configs in the FileTree component (#3868)
  * fix: Fixing CLI option for `--queue-include-unit-reading`
    (#3869)
* Tue Feb 11 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.73.0:
  * Breaking Changes
  - Removal of terragrunt- prefix in flags
    All Terragrunt CLI flags no longer start with the terragrunt-
    prefix. This will not immediately break workflows, but will
    start to emit warnings for users.
    We will announce removal of support for flags without the
    terragrunt- prefix well in advance, and it will be done in a
    future minor release before v1.0.
    You can opt in to making this a breaking change today via
    usage of the terragrunt-prefix-flags strict control.
  - Rename of TERRAGRUNT_ prefixed environment variables
    All Terragrunt environment variables are no longer prefixed
    with TERRAGRUNT_, but are now instead prefixed with TG_. This
    will not immediately break workflows, but will start to emit
    warnings for users.
    We do not currently have plans to remove support for
    environment variables with the TERRAGRUNT_ prefix, and are
    aiming to support them after the release of v1.0, as we know
    this can be a more difficult configuration to change.
    You can opt in to making this a breaking change today via
    usage of the terragrunt-prefix-env-vars strict control.
  - Removal of support for the Terragrunt default command
    Prior to this release, Terragrunt would forward all commands
    that were not defined in the Terragrunt CLI directly to
    OpenTofu/Terraform. With the introduction of the new run
    command, this behavior is no longer necessary, nor desirable.
    In addition to supporting the new run command, Terragrunt now
    also supports explicit OpenTofu shortcuts. You can learn more
    about both below.
    We will announce removal of support for the default command
    of Terragrunt well in advance, and it will be done in a
    future minor release before v1.0.
    You can opt in to making this a breaking change today via
    usage of the default-command strict control.
  * New Features
    All of the features released in this release require usage of
    the cli-redesign experiment.
  - New run command
    This command replaces what used to be the responsibility of
    the default command in Terragrunt. Going forward, when users
    want to explicitly have Terragrunt run an OpenTofu/Terraform
    command on their behalf, they'll use the run command.
    In a future release, this command will also gain the two
    following flags to replace the functionality of the run-all
    and graph commands:
  - -all: Replaces the run-all command.
  - -graph: Replaces the graph command.
    You can learn more about the run command here:
    https://terragrunt.gruntwork.io/docs/reference/cli-options/#run
  - New exec command
    This command provides tooling to explicitly execute an
    arbitrary command using Terragrunt (even if it's not related
    to OpenTofu/Terraform). It users additional control over
    exactly what Terragrunt does when it's executing a command,
    and gives them additional flexibility they wouldn't have
    otherwise.
    You can learn more about the exec command here:
    https://terragrunt.gruntwork.io/docs/reference/cli-options/#exec
  - New info strict command
    The new info strict command gives users a quick way to
    determine which strict controls are available in the
    Terragrunt CLI using the terminal.
    We'll be making updates in the near future to update the
    UI/UX of the command, but we've released an early version for
    preview via the cli-redesign experiment flag.
  * What's Changed
  - fix: Fixing slug for `cli-redesign` migration guide (#3866)
  - feat: `exec`, `run`, `info strict` commands implementation,
    flags renaming. (#3723)
  - fix: Closing gap from CLI Redesign (#3862)
* Sat Feb  8 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.72.9:
  * Stacks: output (#3796)
  * fix: Cleaning up docs bugs (#3856)
  * feat: Adding version lookup to engine docs (#3854)
  * feat: Updating TODO.md with reference to new custom domain for
    site rewrite (#3853)
  * feat: Adding site-wide banner to collect feedback (#3852)
  * feat: Add broken link checking to Starlight docs (#3849)
  * build(deps): bump ruby/setup-ruby from 1.207.0 to 1.215.0
    (#3832)
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.72.8 (0.72.7 was not released):
  * Dependencis update (#3855)
  * feat: Adding Docker Compose for local dev (#3847)
  * feat: Content parity with prod docs (#3844)
  * feat: Add office hours banner (#3843)
  * feat: Add incomplete Starlight rewrite of docs site (#3760)
  * feat: Adding a `SECURITY.md` file (#3827)
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.72.6:
  * Dependencies update (#3826)
  * feat: Improve handling of ExcludeFromCopy configuration in
    Terragrunt (#3816)
  * Windows long path enable in CICD (#3819)
  * Further document `--terragrunt-auth-provider-cmd` and redo the
    contents. (#3798)
  * docs: Adding OpenTofu/Terraform debugging guidance (#3813)
  * docs: Adding more practical example of the exclude block
    (#3812)
  * No proxy build fix (#3801)
  * fix: Adjusting testing for GCS bucket existence check (#3810)
* Mon Jan 27 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.72.5:
  * Fix confusing error message gcp (#3756)
  * Dependencies update (#3803)
  * build(deps): bump github.com/zclconf/go-cty from 1.16.0 to
    1.16.1 (#3790)
  * build(deps): bump go.opentelemetry.io/otel from 1.33.0 to
    1.34.0 (#3789)
* Thu Jan 23 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.72.4:
  * Improved errors retry/ignore (#3795)
  * Code spell issues fixes (#3799)
* Wed Jan 22 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.72.3:
  * fix #3784 add support for using `h`,`j`,`k`,`l` in catalog
    command. (#3797)
  * feat: Adjusting Getting Started docs (#3788)
  * build(deps): bump github.com/hashicorp/go-getter from 1.7.6 to
    1.7.8 (#3786)
  * build(deps): bump github.com/ProtonMail/go-crypto from 1.1.3 to
    1.1.5 (#3785)
  * docs: Adding testing docs for contributors (#3787)
  * docs: Adding linting docs to the contribution page (#3783)
  * build(deps): bump golang.org/x/oauth2 from 0.24.0 to 0.25.0
    (#3754)
  * build(deps): bump github.com/charmbracelet/bubbletea from 1.1.0
    to 1.2.4 (#3755)
  * fix: Fixing notification truncation (#3781)
  * fix: Adding truncation to release announcement (#3780)
  * Add stack run * documentation (#3778)
  * fix: Revert accidental early removal of `--terragrunt` prefix
    from log formatting (#3779)
  * docs: Shuffling docs ordering with permalinks (#3777)
* Fri Jan 17 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.72.2:
  * Fixed broken links on expermient pages (#3776)
  * Revert "docs: Shuffling docs ordering (#3768)" (#3775)
  * docs: Shuffling docs ordering (#3768)
  * Update status of stacks experiment (#3774)
  * fix: Addressing #3586 review feedback (#3773)
  * Stacks: run (#3762)
  * feat: add encryption to remote_state (#3586)
* Thu Jan 16 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.72.1:
  * fix: set ExcludeFromCopy correctly (#3766)
  * fix: Adjusting Discord invite link (#3761)
  * fix(docs): correct typo in stacks.md (#3758)
  * fix: Adjusting delay to reduce flakiness (#3748)
  * Discord link update (#3747)
* Sat Jan 11 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.72.0:
  * Tofu 1.9.0 support (#3746)
  * fix: Adjusting docs for install (#3745)
  * fix: Fixing race condition in
    `TestDownloadTerraformSourceFromLocalFolderWithManifest` test
    (#3744)
* Fri Jan 10 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.71.5:
  * fix: Flush buffer early so that users still get streamed logs
    (#3742)
  * fix: Removing integrity check on hubspot script (#3739)
* Fri Jan 10 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.71.4:
  * Added exclude_from_copy to config (#3543)
* Fri Jan 10 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.71.3:
  * Updated stack version to point to main (#3743)
  * Stacks: generate (#3627)
  * Fixed discord link (#3740)
  * build(deps): bump github.com/gruntwork-io/boilerplate (#3725)
  * build(deps): bump github.com/aws/aws-sdk-go-v2 from 1.32.5 to
    1.32.7 (#3729)
  * build(deps): bump ruby/setup-ruby from 1.204.0 to 1.207.0
    (#3728)
  * build(deps): bump golang.org/x/term from 0.27.0 to 0.28.0
    (#3727)
  * build(deps): bump github.com/zclconf/go-cty from 1.15.1 to
    1.16.0 (#3726)
  * fix: Fixing some broken links (#3736)
  * Feat/add subscribe banner (#3731)
* Tue Jan  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.71.2:
  * fix: Use correct cache while parsing partial config (#3701)
  * Update hclfmt documentation (#3702)
  * Minor Code Improvements (#3718)
  * Dependencies update (#3716)
  * Feature flags concurrency fix (#3713)
  * feat: Adding `%%tf-command` log placeholder for custom format
    (#3709)
  * fix: Updating Discord link for website (#3697)
  * fix: Rephrasing missing dependency a bit (#3695)
  * Enhanced clarity of error messages for missing mock outputs
    when using the dependencies block, fix #3567 (#3692)
* Sat Dec 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.71.1:
  * feat: Adding `log-disable-error-summary` flag (#3687)
* Sat Dec 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.71.0:
  * feat: Adding logging docs (#3688)
  * fix: Split stdout and stderr streams even when using custom
    logging (#3686)
* Thu Dec 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.70.4:
  * fix: Fixing configurable `root` include (#3683)
  * fix: Fixing `root-file-name` default (#3682)
* Thu Dec 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.70.3:
  * build(deps): bump
    go.opentelemetry.io/otel/exporters/otlp/otlpmetric/otlpmetricgrpc
    (#3666)
  * build(deps): bump
    go.opentelemetry.io/otel/exporters/stdout/stdoutmetric (#3664)
  * build(deps): bump
    go.opentelemetry.io/otel/exporters/otlp/otlpmetric/otlpmetrichttp
    (#3663)
  * build(deps): bump go.opentelemetry.io/otel from 1.32.0 to
    1.33.0 (#3662)
  * build(deps): bump filippo.io/age from 1.2.0 to 1.2.1 (#3680)
* Thu Dec 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.70.2:
  * fix: Adding `tf-command-args` support (#3679)
* Thu Dec 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.70.1:
  * fix: Adding GitHub Enterprise support for catalog (#3678)
* Thu Dec 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.70.0:
  * fix: Reintroduce symlink work behind experiment flag (#3672)
  * feat: Deprecating `terragrunt.hcl` as root (#3588)
  * fix: Adding redirect entries for all the pages that were
    renamed (#3676)
  * Lint fixes (#3670)
  * Updated json formatting (#3668)
  * chore: Reorganizing the features section of the docs (#3640)
  * build(deps): bump google.golang.org/grpc from 1.68.0 to 1.68.1
    (#3638)
  * build(deps): bump ruby/setup-ruby from 1.202.0 to 1.204.0
    (#3660)
  * build(deps): bump github.com/stretchr/testify from 1.9.0 to
    1.10.0 (#3634)
  * build(deps): bump github.com/charmbracelet/lipgloss from 0.13.0
    to 1.0.0 (#3635)
  * build(deps): bump github.com/zclconf/go-cty from 1.14.2 to
    1.15.1 (#3636)
  * build(deps): bump golang.org/x/oauth2 from 0.23.0 to 0.24.0
    (#3637)
  * fix: `ProviderCacheWithProviderCacheDir` test (#3656)
* Sat Dec 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.69.13:
  * Don't require HOME if TERRAGRUNT_PROVIDER_CACHE_DIR is set
    (#3649)
  * Add redirect for unused contact page. (#3653)
  * feat: Incorporating user feedback on the Getting Started guide
    (#3648)
* Fri Dec 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.69.12:
  * fix #3169 allow `endpoints.s3` in `remote_state` block. (#3643)
* Fri Dec 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.69.11:
  * build(deps): bump golang.org/x/crypto from 0.28.0 to 0.31.0
    (#3650)
  * Add missed close parenthesis (#3651)
  * chore: Adding signature verification docs (#3647)
* Wed Dec 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.69.10:
  * fix: TF output log level (#3646)
  * feat: Add Discord logo  (#3641)
  * chore: Reorganize Getting Started Guide (#3632)
  * fix: Deprecating legacy exclude and error configurations
    (#3625)
* Sun Dec  8 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.69.9:
  * zip archive extraction (#3630)
  * build(deps): bump github.com/charmbracelet/bubbles from 0.16.1
    to 0.20.0 (#3612)
  * build(deps): bump github.com/creack/pty from 1.1.17 to 1.1.24
    (#3613)
* Fri Dec  6 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.69.8:
  * Improve negative error pattern handling (#3621)
  * fix: Fixing some broken links in the docs (#3623)
* Thu Dec  5 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.69.7:
  * add new built-in function get_aws_account_aliases(), fix #2483
    (#3607)
* Wed Dec  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.69.6:
  * Errors block (#3584)
* Wed Dec  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.69.5 (0.69.4 was not released):
  * fix: Fixing concurrent access to read files map (#3615)
  * build(deps): bump
    go.opentelemetry.io/otel/exporters/otlp/otlptrace/otlptracehttp
    (#3595)
  * build(deps): bump
    go.opentelemetry.io/otel/exporters/otlp/otlpmetric/otlpmetricgrpc
    (#3597)
  * build(deps): bump github.com/ProtonMail/go-crypto (#3598)
  * add `--terragrunt-hclfmt-exclude-dir` parameter `hclfmt`
    command. fix #3391 (#3609)
* Fri Nov 29 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.69.3:
  * fix: `error_hook` processing (#3608)
* Fri Nov 29 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.69.2:
  * fix: Wrap TF stdout and stderr in JSON (#3602)
  * wrong environment name on document (#3600)
  * build(deps): bump github.com/aws/aws-sdk-go-v2 from 1.30.3 to
    1.32.5 (#3594)
  * build(deps): bump cloud.google.com/go/storage from 1.46.0 to
    1.47.0 (#3593)
* Tue Nov 26 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.69.1:
  * feat: Adding test for slash in source name (#3591)
  * fix: Adjusting `run-all` docs (#3589)
  * feat: `-detailed-exitcode` with `run-all` commands (#3585)
* Wed Nov 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.69.0:
  * chore: Pin tflint to `v0.50.3` (#3569)
* Wed Nov 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.68.17:
  * feat: support discovery of symlinked modules (#3562)
  * feat: Improving the quick start experience (#3568)
  * fix: Adjusting docs for `feature` and `exclude` (#3581)
* Wed Nov 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.68.16:
  * Add handling of empty feature blocks (#3580)
  * fix: Fix spelling of `RenderJSONithMetadata` as
    `RenderJSONWithMetadata` (#3579)
  * Exclude block (#3551)
* Tue Nov 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.68.15:
  * Custom Log Formatting (#3537)
  * build(deps): bump
    go.opentelemetry.io/otel/exporters/otlp/otlpmetric/otlpmetrichttp
    (#3576)
  * build(deps): bump github.com/hashicorp/terraform-svchost
    (#3577)
  * build(deps): bump github.com/hashicorp/hcl/v2 from 2.22.0 to
    2.23.0 (#3575)
  * build(deps): bump google.golang.org/grpc from 1.67.1 to 1.68.0
    (#3574)
  * build(deps): bump github.com/hashicorp/go-plugin from 1.6.1 to
    1.6.2 (#3573)
* Tue Nov 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.68.14:
  * feat: Adding Terminology docs (#3559)
  * feat: Integrate includes into units reading (#3563)
  * chore: Cleaning up OIDC Work (#3554)
* Thu Nov 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.68.13:
  * feat: Adding units-reading (#3550)
  * feat: Adding Discord Markdown badge (#3539)
  * docs: Adding documentation for release process (#3487)
  * fix: Refactoring out helpers (#3465)
  * fix: Re-introducing `--terragrunt-hclfmt-file` docs (#3552)
* Wed Nov 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.68.12 (0.68.11 does not exist):
  * Allow hcl format from stdin (#3288)
  * build(deps): bump
    go.opentelemetry.io/otel/exporters/stdout/stdouttrace (#3546)
  * build(deps): bump
    go.opentelemetry.io/otel/exporters/stdout/stdoutmetric (#3548)
  * build(deps): bump golang.org/x/term from 0.25.0 to 0.26.0
    (#3547)
  * build(deps): bump github.com/hashicorp/go-getter/v2 from 2.2.1
    to 2.2.3 (#3545)
  * build(deps): bump ruby/setup-ruby from 1.199.0 to 1.202.0
    (#3549)
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.68.10:
  * Improved errors handling for HCL functions (#3544)
  * Update config doc to fix terragrunt-diff typo (#3515)
  * build(deps): bump
    go.opentelemetry.io/otel/exporters/otlp/otlpmetric/otlpmetricgrpc
    (#3501)
  * build(deps): bump github.com/charmbracelet/glamour from 0.6.0
    to 0.8.0 (#3493)
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.68.9:
  * Feature flags parsing (#3513)
  * docs(cli-options): add a warning message about non-functionnal
    glob curly braces expansion for TERRAGRUNT_INCLUDE_DIR and
    TERRAGRUNT_EXCLUDE_DIR env variables (#3516)
  * build(deps): bump
    go.opentelemetry.io/otel/exporters/otlp/otlptrace/otlptracegrpc
    from 1.23.0 to 1.31.0 (#3503)
  * build(deps-dev): bump rexml from 3.3.6 to 3.3.9 in /docs
    (#3522)
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.68.8:
  * Implement terragrunt-dont-check-dependent-modules flag (#3534)
  * build(deps): bump cloud.google.com/go/storage from 1.44.0 to
    1.46.0 (#3530)
  * build(deps): bump ruby/setup-ruby from 1.196.0 to 1.199.0
    (#3531)
* Fri Nov  1 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.68.7:
  * Add provider cache offline errors handling  (#3527)
* Tue Oct 29 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.68.6:
  * Updated --terragrunt-out-dir / --terragrunt-json-out-dir to
    handle relative paths.
- Update to version 0.68.5:
  * Added strict flag for improved performance in dependency
    processing
  * You can now enhance performance by setting the environment
    variable:
    TERRAGRUNT_STRICT_CONTROL="skip-dependencies-inputs"
    This will skip input processing for dependencies, leading to
    faster execution times when running Terragrunt.
  * Improved CI/CD pipeline to build without Go proxy and detect
    checksum changes.
  * Enhanced error messages for invalid strict control flags.
  * Updated dependencies for better performance and stability.
  * Refined scaffold documentation.
  * Fixed panic issue in Sops decryption.
  * Corrected handling of pseudo-tty commands.
* Thu Oct 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.68.4:
  * chore: Updating deps (#3480)
  * CICD updates (#3467)
  * feat: Upgrading `go-getter` to v2 in scaffold (#3455)
* Wed Oct 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.68.3:
  * feat: Adding Strict Package (#3424)
* Wed Oct 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.68.2:
  * Fixing modules output corruption (#3459)
  * Redirect engine messages to stderr (#3468)
* Fri Oct 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.68.1:
  * fix: Removing non non-interactive logic in err stream redirect
    (#3464)
* Fri Oct 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.68.0:
  * Suppressing `423` error in Terragrunt Provider Cache (#3453)
  * Fix concurrent map write due to read lock and delete (#3457)
  * fix(init): do not require re-init after explicit init on clean
    directory (#2949)
  * feat: support merging the "skip" attribute from included files.
    (#3225)
  * build(deps): bump webrick from 1.8.1 to 1.8.2 in /docs (#3436)
* Sun Oct  6 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.67.16:
  * Handling of redirected input (#3451)
* Wed Oct  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.67.15:
  * Engine log level propagation (#3443)
* Fri Sep 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.67.14:
  * fix: Use env vars for `sops_decrypt_file` (#3439)
* Fri Sep 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.67.13:
  * CVE fixes and dependencies update (#3435)
* Fri Sep 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.67.12:
  * Fixing registry host discovery (Terragrunt Provider Cache)
    (#3432)
  * Fixing converting absolute paths to relative in logs (#3433)
* Wed Sep 25 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.67.11:
  * feat: introducing "copy_terraform_lock_file" to fine tune Lock
    File Handling (#2889)
* Sat Sep 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.67.10:
  * Improved errors printing in case of terraform/tofu invocation
    (#3423)
  * feat: Adding release announcement workflow (#3419)
* Sat Sep 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.67.9:
  * fix: update repository for catalog command (#3415)
  * feat: Adding issue templates (#3416)
  * feat: Adding `codespell` to Automatically Check Spelling
    (#3413)
* Sat Sep 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.67.8:
  * User-friendly error for invalid envs/flags (#3414)
* Sat Sep 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.67.7:
  * Downloading of latest engine (#3412)
  * feat: Adding `stylecheck` lint (#3354)
* Sat Sep 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.67.6:
  * Fixing output STDOUT logs to `stdout` (#3409)
  * Allow pre-release versions to pass version constraints (#3405)
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.67.5:
  * Fix various logging issues. Log package refactoring. (#3400)
  * feat: Adding `preserved` label exemption to stale check (#3392)
  * Fixed scafold tests (#3396)
* Fri Sep 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.67.4:
  * Added handling of TERRAGRUNT_TEMP_QUOTE_NULL (#3395)
  * Updated download test to fetch changes from main (#3386)
  * TG-251 Test fixtures organisation  (#3380)
* Fri Sep 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.67.3:
  * fix: Reverting changes in #3383 (#3385)
* Fri Sep 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.67.2:
  * 3364 - Update Remote State Encryption When Configurations Are
    Updated (#3383)
  * Migration from master to main (#3379)
  * build(deps-dev): bump rexml from 3.3.3 to 3.3.6 in /docs (#3359)
  * Tests simplification (#3365)
* Fri Sep 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.67.1:
  * Dependencies upgrade (#3374)
* Fri Sep 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.67.0:
  * Log improvements (#3338)
  * Locals doc: Fix/improve 'Reading from other HCL files' (#3361)
  * feat: Adding `thelpher` and `wastedassign` lints (#3352)
  * feat: Split out unessential jobs (#3357)
  * feat: Adding strict lint (#3348)
  * Engine documentation update (#3355)
  * feat: Adding `wsl` lint (#3351)
* Tue Aug 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.66.9:
  * fix: make `terragrunt-fetch-dependency-output-from-state` to
    work with not applied dependencies (#3350)
* Fri Aug 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.66.8:
  * chore: Bumping go to `1.22` (#3346)
* Fri Aug 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.66.7:
  * fix: Fixing remote state init skip (#3345)
  * Adding `test` Lint Presets (#3340)
  * Updated documentation for --terragrunt-graph-root (#3344)
  * fix: Reverting to asserts for non error checking assertions
    (#3341)
* Wed Aug 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.66.6:
  * Engine output handling (#3339)
* Tue Aug 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.66.5:
  * chore: Adding `performance` Lint Preset (#3336)
  * chore: Adding `bugs` Lint Preset (#3334)
* Mon Aug 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.66.4:
  * chore: Bumping `golangci-lint` to `v1.59.1` (#3333)
  * Fix CICD tests for mocks (#3335)
  * chore: Hiding Mocks Tests (#3331)
  * fix: Fixing stale action (#3332)
  * fix: Fixing command not found error (#3330)
  * Add configuration options for AWS S3 server access logging
    (#3006)
  * feat: Add stale issue workflow (#3329)
* Wed Aug  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.66.3:
  * Terragrunt performance improvements (#3307)
* Wed Aug  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.66.2:
  * feat: Adding `TG_CTX_TF_PATH` to hook context (#3323)
  * build(deps-dev): bump rexml from 3.3.1 to 3.3.3 in /docs
    (#3316)
  * build(deps-dev): bump nokogiri from 1.16.3 to 1.16.5 in /docs
    (#3135)
  * add env TERRAGRUNT_EXCLUDE_DIR to docs (#3320)
  * fix: Reference OpenTofu Everywhere We Can (#3319)
* Sat Aug  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.66.1:
  * Adding resolving relative urls to Terragrunt Provider Cache
    (#3318)
  * Fixing interpreting empty list as null value (#3317)
* Fri Aug  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.66.0:
  * chore: Bumping OpenTofu to `v1.8.0` (#3315)
* Fri Aug  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.65.0:
  * `sops_decrypt_file()`: resolve path argument relative to
    `terragrunt.hcl` (#2752)
  * chore: Bumping `gruntwork-io/pre-commit` to `v0.1.23` (#3311)
* Thu Aug  1 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.64.5:
  * Sorting output and fixing minor bugs in `hclvalidate` command
    (#3309)
  * fix: Adjusting docs for engines (#3306)
* Thu Aug  1 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.64.4:
  * Fixing "dependency cycle between modules" when using
    `hclvalidate` command with undefined `config_path` attribute
    (#3305)
* Thu Aug  1 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.64.3:
  * Engine verification (#3300)
* Tue Jul 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.64.2:
  * Adding supply credentials for a third-party registry when using
    Terragrunt Provider Cache (#3303)
* Sat Jul 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.64.1:
  * Adding registry url discovery for Terragrunt Provider Cache
    (#3299)
* Thu Jul 25 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.64.0:
  * Upgrade to Sops 3.9.0 (#3297)
* Thu Jul 25 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.63.8:
  * fix: Fixing dynamic auth for deps (#3293)
* Thu Jul 25 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.63.7:
  * Open Telemetry update (#3291)
* Thu Jul 25 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.63.6:
  * Fixing generation of `provider_installation` block used for
    provider caching (#3290)
* Wed Jul 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.63.5:
  * Add support for engine downloading (#3281)
* Wed Jul 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.63.4:
  * 3274 - fix: Include nothing when value for
    `terragrunt-include-dir` doesn't exist on the filesystem
    (#3286)
* Tue Jul 23 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.63.3:
  * Fixing generation of `provider_installation` block used for
    provider caching (#3280)
  * Updated links to provider caching (#3282)
* Fri Jul 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.63.2:
  * fix: getting dynamic credentials before parsing locals block
    (#3279)
* Thu Jul 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.63.1:
  * chore: add log before executing external command (#3276)
* Thu Jul 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.63.0:
  * fix: Reducing the number of Rs in
    `TERRRAGRUNT_IAM_ASSUME_ROLE_WEB_IDENTITY_TOKEN` (#3272)
* Wed Jul 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.62.3:
  * Add handling of multi line variables description (#3269)
* Tue Jul 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.62.2:
  * fix: diags error when parse remote_state (#3268)
* Tue Jul 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.62.1:
  * Dependencies update (#3266)
* Fri Jul 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.62.0:
  * IaC engine support (#3218)
* Fri Jul 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.61.1:
  * Added passing of extra ENVs to the hook executed command
    (#3263)
  * feat: Adding more documentation on validation (#3262)
  * fix: Fixing Pages Build (#3260)
  * feat: Adding pages GHA build (#3259)
* Thu Jul 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.61.0:
  * Added `hclvalidate` command (#3248)
  * Added `--terragrunt-excludes-file` flag (#3255)
  * fix: Adjusting CODEOWNERS file so that all are recognized as
    codeowners, instead of only the last entry (#3251)
* Wed Jul 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.60.1:
  * Concurrent access write fixes (#3245)
* Wed Jul 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.60.0:
  * Add support for Terraform 1.9 (#3239)
* Wed Jul 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.59.7:
  * Fixed using authentication provider credentials with
    `get_aws_account_id` (#3243)
  * chore: Updating `CODEOWNERS` to include current Terragrunt
    maintainers (#3233)
  * fix: Fixing quick start docs (#3232)
  * chore: switch to gtm for docs site (#3229)
* Wed Jul  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.59.6:
  * build(deps): bump github.com/hashicorp/go-retryablehttp (#3226)
  * build(deps): bump github.com/hashicorp/go-getter from 1.7.4 to
    1.7.5 (#3227)
  * Add script to check GH release assets (#3223)
* Fri Jun 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.59.5:
  * Fixed using dynamic AWS credentials for `remote_state` (#3219)
  * fix: Adjusting language for `--terragrunt-non-interactive` in
    the docs so that it's clearer what it does for users (#3216)
  * feat: Adding more context on why caching partial parsing of
    configs can be useful (#3214)
  * Updated resource class to avoid killing build process (#3213)
  * fix: Fixing cookie policy link (#3212)
* Mon Jun 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.59.4:
  * Fixed fetching compressed data from a network mirror server
    (#3208)
  * Remove TERRAGRUNT_PROVIDER_CACHE_DISABLE_PARTIAL_LOCK_FILE
    reference (#3206)
* Thu Jun 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.59.3:
  * Add support for AssumeRoleWithWebIdentity (#2997)
* Thu Jun 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.59.2:
  * build(deps): bump
    github.com/Azure/azure-sdk-for-go/sdk/azidentity (#3199)
  * chore: Updating copy on README.md (#3200)
* Wed Jun 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.59.1:
  * feat: Adding caching for role assumptions (#3197)
  * feat: Adding initialization check caching (#3193)
  * chore: Updating mac release machine to `macos.m1.medium.gen1`
    (#3186)
* Wed Jun 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.59.0:
  * feat: Moving `cache` to `internal` (#3192)
  * feat: dynamic authentication (#3194)
* Mon Jun 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.58.15:
  * feat: log verbose improvements (#3189)
* Tue Jun  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.58.14:
  * Terragrunt Provider Cache with `providers lock` command (#3176)
* Sat Jun  1 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.58.13:
  * Improved errors printing returned from Sops (#3174)
  * fix: Correcting docs on default binary used by Terragrunt
    (#3173)
  * s/trragrunt/terragrunt/ (#3170)
  * feat: Adding binary signing test (#3166)
* Thu May 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.58.12:
  * fix: init command on every run (#3167)
* Thu May 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.58.11:
  * fix: Revert resource class update (#3164)
  * chore: Bumping CircleCI configs (#3160)
  * Fixed flaky test `TestTerragruntProviderCache` (#3161)
* Fri May 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.58.10:
  * Fixed ignoring `TERRAGRUNT_DOWNLOAD` for dependent modules
    (#3158)
  * fix: Fixing `TestTerraformHelp` (#3154)
  * fix: Fixing some malformed cli-options in docs (#3152)
  * fix: get rid of testdata archives (#3155)
* Wed May 22 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.58.9:
  * Improved logging for S3 bucket encryption (#3147)
  * Fixed subcommand actions wrapping (#3144)
  * Cleaning up docs (#3149)
  * feat: Improving `locals` documentation (#3148)
* Tue May 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.58.8:
  * fix: s3 source handling (#3146)
* Sun May 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.58.7:
  * Support all `provider_installation` methods with provider cache
    (#3133)
* Sat May 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.58.6:
  * fix: terraform source url handling (#3142)
* Sat May 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.58.5:
  * Docs and tests fixes (#3136)
* Sat May 11 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- add Makefile and PACKAGING_README.md, remove services from
  `_service`. Upstream changes break the go module vendoring, so we
  can no longer use the go_modules service
* Fri May 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.58.4:
  * Updated makefile to generate mocks before build (#3126)
  * Usage of locks when copy metadata fields (#3124)
* Wed May  8 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.58.3:
  * Added Terraform lock file generation with provider caching (#3108)
* Fri May  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.58.2:
  * Fixed handling of module prefixes (#3104)
  * Bump CI image (#3116)
  * Get rid of third party code (#3114)
* Thu May  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.58.1:
  * Added `if_disabled` attribute for `generate` block (#3110)
* Thu May  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.58.0:
  * OpenTofu 1.7 (#3111)
  * LIB-75: Replace tfenv and tgswitch with mise (#3094)
* Mon Apr 29 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.57.13:
  * fix(provider_cache): Use more permissive regex search for
    Status Locked (#3105)
  * fix: unit test (#3106)
* Sat Apr 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.57.12:
  * Use OpenTofu by default if available in environment (#3097)
* Fri Apr 26 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.57.11:
  * fix: sync Terraform CLI args for 'show' command (#3075)
* Fri Apr 26 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.57.10:
  * Open Telemetry context propagation (#3098)
  * feat: Adding RFC Form (#3099)
* Wed Apr 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.57.9:
  * Check hash and signature of cached providers (#3055)
  * fix: copyright text (#3091)
* Tue Apr 23 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.57.8:
  * Add support for JSON directory output (#3084)
* Tue Apr 23 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.57.7:
  * Bump github.com/hashicorp/go-getter to 1.7.4 (#3088)
* Tue Apr 23 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.57.6:
  * Get rid of code under BUSL license (#3085)
  * Moved destroy operation to separated section (#3074)
* Fri Apr 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.57.5:
  * build(deps): bump golang.org/x/net from 0.19.0 to 0.23.0
    (#3072)
* Fri Apr 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.57.4:
  * Add support for saving output plan (#3073)
* Fri Apr 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.57.3:
  * Fixes getting output from multiple nested dependencies (#3071)
* Wed Apr 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.57.2:
  * Fixed handling of dependency outputs when json log format is
    enabled (#3049)
  * Fixed 'inputs' typo in docs (#3061)
* Mon Apr 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.57.1:
  * Fixes module requests routing with provider caching (#3057)
  * Improved test for checking aws errors (#3058)
  * Updated terragrunt command execution in parallel tests (#3054)
* Sat Apr 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.57.0:
  * Support for Terraform 1.8 (#3052)
  * docs: update terragrunt supported versions table (#3038)
* Thu Apr 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.56.5:
  * Fixes destroy order for `apply -destroy` alias (#3011)
  * build(deps): bump github.com/docker/docker (#3046)
  * install.md: add for Gentoo, link to Repology (#3044)
* Wed Apr 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.56.4:
  * Caching Terraform providers (#3001)
  * chore: fix function names in comment (#3042)
  * Fix TestTerragruntParallelism (#3045)
  * Flaky tests fixes (#3041)
* Mon Apr  8 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.56.3:
  * Fixes slow destroy of config deeply nested in config hierarchy
    (#3015)
* Fri Apr  5 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.56.2:
  * Conditionally set log level of s3 bucket encryption warning
    (#2878)
  * Add flag for disabling dependent modules identification in
    json-render (#2918)
* Fri Apr  5 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.56.1:
  * terragrunt-info parsing improvement (#2901)
* Fri Apr  5 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.56.0:
  * Add step to test terragrunt with latest terraform version
    (#3035)
  * Downgrading latest officially supported version of Terraform to
    1.5.x (#2936)
* Wed Apr  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.55.21:
  * Remote state errors improvement  (#3032)
* Tue Mar 26 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.55.20:
  * fix: regexp (#3027)
  * terragrunt issue 3017: expand docs for find_in_parent_folder()
    (#3018)
* Sat Mar 23 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.55.19:
  * MacOS binary signer update (#3023)
  * Updated module ci version (#3021)
  * Updated sign binaries parameters for MacOS (#3020)
  * Updated gon version to v0.2.5 (#3019)
  * Scaffold command, fix unable to handle https URL (#3005)
  * Fix grammar in feature text (#3010)
* Tue Mar 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.55.18:
  * build(deps-dev): bump nokogiri and mini_portile2 in /docs
    (#3009)
  * build(deps): bump google.golang.org/protobuf from 1.32.0 to
    1.33.0 (#3000)
  * build(deps-dev): bump nokogiri from 1.10.4 to 1.10.10 in /docs
    (#2929)
  * build(deps): bump github.com/go-jose/go-jose/v3 from 3.0.0 to
    3.0.3 (#2996)
  * build(deps): bump github.com/cloudflare/circl from 1.3.3 to
    1.3.7 (#2995)
* Tue Mar 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.55.17:
  * Add support for opentofu registry (#2961)
* Sun Mar 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.55.16:
  * Terragrunt performance improvements (#2983)
* Sun Mar 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.55.15:
  * Catalog TUI Improvements (#2993)
* Sun Mar 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.55.14:
  * Upgrade sops to v3.8.1 (#2991)
  * Include "modules" path in the module url used in docs for
    scaffold command (#2985)
* Sun Mar 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.55.13:
  * MacOS catalog terminal reset (#2984)
* Sun Mar 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.55.12:
  * Scaffold execution in Windows (#2982)
* Sun Mar 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.55.11:
  * Catalog screen freeze on MacOS (#2978)
* Sun Mar 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.55.10:
  * Catalog terminal freeze (#2962)
* Sat Feb 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.55.9:
  * Fix data race accessing shared slice from goroutines in
    dependency computation. (#2942)
  * Recommending pre-release as a way to mitigate the risk of
    failed releases (#2964)
  * Test for tracking that no errors are printed in HCL files
    parsing (#2947)
* Sat Feb 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.55.8:
  * Fixing typo in the log message when using catalog (#2960)
* Sat Feb 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.55.7:
  * Update go version to 1.21.7 to fix CVEs (#2951)
- BuildRequire go1.21.7 or higher
* Sat Feb 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.55.6:
  * Fix nested dependency parsing (#2957)
* Sat Feb 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.55.5:
  * Add support for OpenTelemetry (#2921)
* Tue Feb 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.55.4:
  * Reference to dependency inputs (#2945)
* Tue Feb 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.55.3:
  * Improved identification of remote state changes (#2939)
* Wed Feb 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.55.2:
  * Improved handling of disabled modules (#2938)
* Tue Feb  6 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.55.1:
  * build(deps): bump github.com/opencontainers/runc from 1.1.9 to
    1.1.12 (#2924)
* Fri Feb  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.55.0:
  * Add graph command to terragrunt (#2871)
* Fri Jan 26 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.54.22:
  * Updated AWS SDK to 1.50.0 (#2906)
* Tue Jan 23 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.54.21:
  * Enhanced Missing Executable Error Messages for Terraform & Tofu
    (#2905)
* Sat Jan 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.54.20:
  * Add support for JSON output format (#2863)
* Thu Jan 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.54.19:
  * Improved parsing of empty tfvars files (#2896)
* Wed Jan 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.54.18:
  * Fix cloning repos for the catalog command. (#2888)
* Mon Jan 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.54.17:
  * Fixed identification of terragrunt cache dir (#2874)
  * Updated CICD to use release version of OpenTofu 1.6.0 (#2887)
* Mon Jan 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.54.16:
  * Fix reading `catalog` configuration (#2884)
* Mon Jan 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.54.15:
  * Manifest file removal in Windows (#2875)
* Mon Jan 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.54.14:
  * Add handling for missing policy bucket (#2881)
* Mon Jan 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.54.13:
  * AWS SDK version upgrade (#2883)
* Thu Jan  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.54.12:
  * Fix built-in `find_in_parent_folders` func (#2869)
  * Usage of tofu 1.6.0-rc1 in tests (#2790)
* Thu Jan  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.54.11:
  * build(deps): bump golang.org/x/crypto from 0.14.0 to 0.17.0
    (#2858)
* Thu Jan  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.54.10:
  * fix: findInParentFolders func (#2866)
* Thu Dec 21 2023 opensuse_buildservice@ojkastl.de
- Update to version 0.54.9:
  * Fix catalog configuration file search. (#2862)
* Wed Dec 20 2023 opensuse_buildservice@ojkastl.de
- Update to version 0.54.8:
  * Speed up repo cloning for the `catalog` command (#2857)
* Tue Dec 19 2023 opensuse_buildservice@ojkastl.de
- Update to version 0.54.7:
  * feat: update the log level from debug to info (#2820)
* Tue Dec 19 2023 opensuse_buildservice@ojkastl.de
- Update to version 0.54.6:
  * Fixed passing assume_role generation (#2853)
* Sat Dec 16 2023 kastl@b1-systems.de
- Update to version 0.54.5:
  * Read the list of repositories for the `catalog` command from
  * the terragrunt configuration file (#2852)
* Fri Dec 15 2023 kastl@b1-systems.de
- Update to version 0.54.4:
  * Non interactive state initialization (#2840)
* Thu Dec 14 2023 kastl@b1-systems.de
- Update to version 0.54.3:
  * Catalog handling https urls (#2850)
* Wed Dec 13 2023 kastl@b1-systems.de
- Update to version 0.54.2:
  * Parse frontmatter data in the `catalog` command  (#2843)
* Mon Dec 11 2023 kastl@b1-systems.de
- Update to version 0.54.1:
  * Fixed passing of module URL from catalog to scaffold (#2842)
  * scaffold blank spaces fix (#2839)
  * Scaffold and catalog documentation fixes (#2838)
* Sat Dec  9 2023 kastl@b1-systems.de
- Update to version 0.54.0:
  * Initial catalog implementation (#2815)
  * Fixed scaffold docs (#2829)
  * Terragrunt scaffold  (#2821)
  * Update regex for version check (#2817)
* Tue Nov 28 2023 kastl@b1-systems.de
- Update to version 0.53.8:
  * Add handling of backend configs (#2810)
* Mon Nov 27 2023 kastl@b1-systems.de
- Update to version 0.53.7:
  * Updated jw v4 dependency version (#2805)
* Thu Nov 23 2023 kastl@b1-systems.de
- Update to version 0.53.6:
  * feat: Support assume_role in s3 backend config. Starting with
    TF1.6 (#2800)
  * Update Arch Linux package URL in install.md (#2802)
* Tue Nov 21 2023 kastl@b1-systems.de
- Update to version 0.53.5:
  * Reverted function name, added test to track usage of function
    (#2801)
  * feat: disallow undefined flags (#2799)
* Fri Nov 17 2023 kastl@b1-systems.de
- Update to version 0.53.4:
  * Add a new built-in function `get_working_dir()` (#2791)
  * Fix TestErrorExplaining (#2793)
  * Add shell completion (#2788)
* Thu Nov 16 2023 kastl@b1-systems.de
- Update to version 0.53.3:
  * Improved explanation of missing aws creds (#2787)
  * Update usage of private repo docs (#2784)
  * Add missing terraform commands (#2780)
* Mon Nov  6 2023 kastl@b1-systems.de
- Update to version 0.53.2:
  * GCP dependencies update (#2775)
* Thu Nov  2 2023 kastl@b1-systems.de
- Update to version 0.53.1:
  * Update aws-sdk to support SSO (#2774)
  * Add Default Retryable Error List to Docs (#2771)
  * test: use `T.Setenv` to set env vars in tests (#2205)
* Mon Oct 30 2023 kastl@b1-systems.de
- Update to version 0.53.0:
  * Terraform 1.6 (#2754)
* Fri Oct 27 2023 kastl@b1-systems.de
- Update to version 0.52.7:
  * Bump google.golang.org/grpc from 1.55.0 to 1.56.3 (#2767)
* Fri Oct 27 2023 kastl@b1-systems.de
- Update to version 0.52.6:
  * fix!: output-module-groups to work like run-all (#2769)
  * Update tofu version to 1.6.0-alpha3 (#2766)
* Wed Oct 25 2023 kastl@b1-systems.de
- Update to version 0.52.5:
  * feat: add read_tfvars_file function (#2757)
* Sat Oct 21 2023 kastl@b1-systems.de
- Update to version 0.52.4:
  * Add linting of source code (#2743)
* Sat Oct 14 2023 kastl@b1-systems.de
- Update to version 0.52.3:
  * Bump golang.org/x/net from 0.15.0 to 0.17.0 (#2755)
* Fri Oct 13 2023 kastl@b1-systems.de
- Update to version 0.52.2:
  * Add option to skip S3 credentials validation (#2753)
* Sun Oct  8 2023 kastl@b1-systems.de
- Update to version 0.52.1:
  * Dependent modules scanning improvements (#2749)
  * Add opentofu notice (#2738)
* Fri Oct  6 2023 kastl@b1-systems.de
- Update to version 0.52.0:
  * Add OpenTofu support (#2745)
* Thu Oct  5 2023 kastl@b1-systems.de
- Update to version 0.51.9:
  * Update render-json to include list of dependent modules (#2740)
  * refactor: fix usage of deprecated calls to io/ioutil package
    (#2742)
* Wed Oct  4 2023 kastl@b1-systems.de
- Update to version 0.51.8:
  * Add check for aws session before checking S3 bucket (#2739)
  * docs: removes two errors in the markdown (#2741)
* Fri Sep 29 2023 kastl@b1-systems.de
- Update to version 0.51.7:
  * State file handling improvements (#2735)
* Thu Sep 28 2023 kastl@b1-systems.de
- Update to version 0.51.6:
  * Updated dependencies to fix security issues (#2733)
* Wed Sep 27 2023 kastl@b1-systems.de
- Update to version 0.51.5:
  * #2280 Add validation of generate blocks from includes (#2281)
* Thu Sep 21 2023 kastl@b1-systems.de
- Update to version 0.51.4:
  * fix: make `auto-init` respect `-no-color` flag (#2722)
  * Add built-in function `get_default_retryable_errors` (#2725)
* Wed Sep 20 2023 kastl@b1-systems.de
- Update to version 0.51.3:
  * Add debug log message to print chdir option (#2724)
* Wed Sep 20 2023 kastl@b1-systems.de
- Update to version 0.51.2:
  * S3 bucket errors handling (#2721)
* Tue Sep 19 2023 kastl@b1-systems.de
- Update to version 0.51.1:
  * Removes trailing slash appended to the end of
    `get_path_to_repo_root()` (#2719)
* Mon Sep 18 2023 kastl@b1-systems.de
- Update to version 0.51.0:
  * Updated to go 1.21 (#2715)
* Fri Sep 15 2023 kastl@b1-systems.de
- Update to version 0.50.17:
  * Add enabled property for dependency (#2712)
* Wed Sep 13 2023 kastl@b1-systems.de
- Update to version 0.50.16:
  * Improved checking of windows console errors (#2711)
* Wed Sep 13 2023 kastl@b1-systems.de
- Update to version 0.50.15:
  * Fixed searching for configs with non-default names #2704.
    (#2704)
  * Updating link to before-and-after-hooks (#2708)
* Thu Sep  7 2023 kastl@b1-systems.de
- Update to version 0.50.14:
  * Terragrunt version in AWS API Calls (#2701)
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.50.13:
  * Module path checking improvements (#2700)
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.50.12:
  * Updated setting of fetch depednency flag (#2699)
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.50.11:
  * feat: disable terraform command validation (#2697)
  * Prevent `init` command from parallel running if plugin cache is
    used (#2698)
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.50.10:
  * GCS remote state configuration prefix (#2695)
  * Move shared libraries to go-commons repository (#2688)
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.50.9:
  * Improved handling of errors from AWS API (#2684)
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.50.8:
  * TFLint configuration loading from hook parameters (#2683)
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.50.7:
  * fix: terraform console command in non-interactive mode (#2686)
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.50.6:
  * Google Cloud impersonate fixes (#2679)
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.50.5:
  * Add terraform command validation (#2676)
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.50.4:
  * Null vars file cleanup (#2672)
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.50.3:
  * Logrus dependency update (#2665)
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.50.2:
  * fix: "null" values in json for aws policy (#2667)
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.50.1:
  * Prevent parsing of excluded modules (#2664)
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.50.0:
  * Pass null values in Terraform inputs (#2663)
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.49.1:
  * Update CircleCI config to sign MacOS binaries (#2661)
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.49.0:
  * TFLint variables and arguments (#2645)
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.48.7:
  * Refactoring cli related code (#2608)
* Thu Aug  3 2023 kastl@b1-systems.de
- Update to version 0.48.6:
  * Simplified run-all confirmation dialog (#2653)
* Tue Aug  1 2023 kastl@b1-systems.de
- Update to version 0.48.5:
  * Add a "output-module-groups" command (#2130)
  * Updated CLI flag wording (#2647)
  * Bump tzinfo from 1.2.7 to 1.2.10 in /docs (#2207)
  * Bump nokogiri from 1.13.6 to 1.14.3 in /docs (#2526)
* Thu Jul 20 2023 kastl@b1-systems.de
- Update to version 0.48.4:
  * Add CLI flags to set handling state buckets (#2644)
* Tue Jul 18 2023 kastl@b1-systems.de
- Update to version 0.48.3:
  * Added handling of no outputs in render-json execution (#2635)
* Tue Jul 18 2023 kastl@b1-systems.de
- Update to version 0.48.2:
  * fix: include missing param in parsing cache key construction
    (#2518)
  * [skip ci] Removing former Grunts (#2640)
  * Update scripts.html (#2638)
* Thu Jul  6 2023 kastl@b1-systems.de
- Update to version 0.48.1:
  * Updated source version identification (#2630)
  * Update documentation to reference Terragrunt Github action
    (#2628)
  * [skip ci] git-xargs programmatic commit (#2623)
* Tue Jun 27 2023 kastl@b1-systems.de
- Update to version 0.48.0:
  * Add support for Terraform 1.5 (#2616)
  * Circleci resource_class update (#2609)
* Fri Jun 16 2023 kastl@b1-systems.de
- Update to version 0.47.0:
  * Go upgrade to 1.20 (#2605)
- BuildRequire go1.20
* Mon Jun 12 2023 kastl@b1-systems.de
- Update to version 0.46.3:
  * #2595 Fix for fetching reference value with slashes (#2597)
* Mon Jun 12 2023 kastl@b1-systems.de
- Update to version 0.46.2:
  * feat: support git tag in `--terragrunt-source-map` option
    (#2586)
* Fri Jun  2 2023 kastl@b1-systems.de
- Update to version 0.46.1:
  * Fixed reading of outputs during destroy (#2589)
* Fri Jun  2 2023 kastl@b1-systems.de
- Update to version 0.46.0:
  * fix: redirecting stdout to stderr in hook commands (#2587)
* Wed May 31 2023 kastl@b1-systems.de
- Update to version 0.45.18:
  * feat: implement hclfmt diff output (#2570)
* Wed May 31 2023 kastl@b1-systems.de
- Update to version 0.45.17:
  * fix: checking dependent modules in `destroy` command (#2581)
* Thu May 25 2023 kastl@b1-systems.de
- Update to version 0.45.16:
  * Add support for Disable field in generate blocks (#2497)
* Mon May 22 2023 kastl@b1-systems.de
- Update to version 0.45.15:
  * Simplified source code locking/unlocking (#2576)
* Fri May 19 2023 kastl@b1-systems.de
- Update to version 0.45.14:
  * #2566 Update error message to include module directory (#2574)
* Wed May 17 2023 kastl@b1-systems.de
- Update to version 0.45.13:
  * feat: add `timecmp` config function (#2571)
* Wed May 17 2023 kastl@b1-systems.de
- Update to version 0.45.12:
  * Handle provider lock file when fetching dependency outputs
    (#2568)
  * Update aws-auth.md (#2563)
  * Add missing IAM Permissions s3:PutBucketOwnershipControls to
    docs this is required now with TG versions starting from
    v0.45.4 (#2562)
* Thu May 11 2023 kastl@b1-systems.de
- Update to version 0.45.11:
  * fix: disable sending a second interrupt signal to `terraform`
    (#2559)
* Tue May  9 2023 kastl@b1-systems.de
- Update to version 0.45.10:
  * fix: avoid double-rendering `terraform init` output (#2558)
* Fri May  5 2023 kastl@b1-systems.de
- Update to version 0.45.9:
  * Fix parsing output when AWS CSM is enabled (#2554)
  * Moved issue template files to ISSUE_TEMPLATE directory (#2555)
  * Add issues templates (#2553)
* Tue May  2 2023 kastl@b1-systems.de
- Update to version 0.45.8:
  * Lazily evaluate the IAM Role (#2507)
* Tue May  2 2023 kastl@b1-systems.de
- Update to version 0.45.7:
  * Mozilla sops upgrade to v3.7.3 (#2549)
* Sun Apr 30 2023 kastl@b1-systems.de
- Update to version 0.45.6:
  * JSON output prefix update (#2548)
* Fri Apr 28 2023 kastl@b1-systems.de
- Update to version 0.45.5:
  * Add explanation for terraform errors (#2547)
* Thu Apr 20 2023 kastl@b1-systems.de
- Update to version 0.45.4:
  * Update S3 bucket creation to pass ObjectOwnership (#2540)
  * ~ aws-auth docs - iam remove object level actions from the
    bucket resource (#2533)
* Tue Apr 18 2023 kastl@b1-systems.de
- Update to version 0.45.3:
  * #2512 Improve reporting errors on modules (#2527)
* Thu Apr  6 2023 kastl@b1-systems.de
- Update to version 0.45.2:
  * #2515 Add option to disable module output (#2516)
* Tue Apr  4 2023 kastl@b1-systems.de
- Update to version 0.45.1:
  * Add --terragrunt-include-module-prefix option (#2493)
  * [skip ci] Refactor contexts (#2503)
  * Update v0.45.0 link title (#2491)
* Fri Mar 17 2023 kastl@b1-systems.de
- Update to version 0.45.0:
  * #2488 Terraform dependencies upgrade (#2489)
  * Add automatic lock release (#2487)
  * Add comment for sourceChangeLocks variable (#2476)
* Wed Mar  8 2023 kastl@b1-systems.de
- Update to version 0.44.5:
  * #2471 Include in download directory tflint config (#2474)
* Fri Mar  3 2023 kastl@b1-systems.de
- Update to version 0.44.4:
  * chore: Add access_token support for the GCS remote state
    backend config (#2463)
* Fri Mar  3 2023 kastl@b1-systems.de
- Update to version 0.44.3:
  * Bump golang.org/x/net from 0.5.0 to 0.7.0 (#2455)
* Thu Mar  2 2023 kastl@b1-systems.de
- Update to version 0.44.2:
  * Bump github.com/hashicorp/go-getter from 1.6.2 to 1.7.0 (#2454)
* Tue Feb 28 2023 kastl@b1-systems.de
- Update to version 0.44.1:
  * #2467 Parallel TFLint execution errors (#2469)
* Thu Feb 23 2023 kastl@b1-systems.de
- Update to version 0.44.0:
  * isRetryable also checks the stdout (#2464)
* Wed Feb 22 2023 kastl@b1-systems.de
- Update to version 0.43.3:
  * #2450 Improved loading of TFLint configuration (#2456)
  * #2417 Add handling of intermittent errors in fixture-stack tests (#2439)
* Sat Feb  4 2023 kastl@b1-systems.de
- Update to version 0.43.2:
  * Improved handling of default value for sse_algorithm (#2438)
* Thu Feb  2 2023 kastl@b1-systems.de
- Update to version 0.43.1:
  * fix AES256 encryption validation (#2337)
  * Fix typos (#2406)
  * [skip ci] Added FUNDING.yml (#2429)
  * Flaky TestInputsToTflintVar fix (#2427)
* Fri Jan 20 2023 kastl@b1-systems.de
- Update to version 0.43.0:
  * feat: update tflint to v0.44.1 (#2422)
  * Remove GITHUB_OAUTH_TOKEN from tflint + update docs (#2424)
* Fri Jan 13 2023 kastl@b1-systems.de
- Update to version 0.42.8:
  * Updated golang.org/x/crypto dependency (#2412)
* Fri Jan  6 2023 kastl@b1-systems.de
- Update to version 0.42.7:
  * #2377 MockOutputs validation before merge (#2379)
* Thu Jan  5 2023 kastl@b1-systems.de
- Update to version 0.42.6:
  * Update error message (#2404)
* Fri Dec 16 2022 kastl@b1-systems.de
- Update to version 0.42.5:
  * Fix debug log for GITHUB_TOKEN for tflint (#2395)
* Fri Dec 16 2022 kastl@b1-systems.de
- Update to version 0.42.4:
  * Expose a token for tflint  (#2387)
  * Fix typo (#2383)
  * Add tflint as built-in hook (#2362)
* Fri Dec  2 2022 kastl@b1-systems.de
- Update to version 0.42.3:
  * #2347 - add --terragrunt-global-cache support to run_cmd (#2348)
* Wed Nov 30 2022 kastl@b1-systems.de
- Update to version 0.42.2:
  * Improve encryption setting on access log bucket (#2375)
* Wed Nov 30 2022 kastl@b1-systems.de
- Update to version 0.42.1:
  * Feat(#2292) add accesslogging bucket tags property to remote state s3 config block (#2355)
  * Update documentation to reference actions for S3 bucket configuration (#2366)
* Tue Nov 29 2022 kastl@b1-systems.de
- Update to version 0.42.0:
  * #1717 Enable security layers for access logging buckets (#2367)
* Thu Nov 24 2022 kastl@b1-systems.de
- Update to version 0.41.0:
  * Go 1.18 upgrade (#2365)
* Tue Nov 15 2022 kastl@b1-systems.de
- Update to version 0.40.2:
  * Bump `golang.org/x/text` and `golang.org/x/net` (#2341)
  * #2331 - fix(docs): Fixes azs in the quick start example (#2340)
* Tue Nov 15 2022 kastl@b1-systems.de
- Update to version 0.40.1:
  * fix: protect sops cache from multiple parallel writes (#2352)
* Tue Nov 15 2022 kastl@b1-systems.de
- Update to version 0.40.0:
  * Add support for Terraform 1.3 (#2308)
  * Fix installation of goimports (#2339)
  * fix: modified single quotes to back quotes. (#2310)
* Tue Oct 18 2022 kastl@b1-systems.de
- Update to version 0.39.2:
  * Navbar we are hiring fix (#2321)
  * navbar - update we are hiring (#2313)
  * Fix a mistake in markdown (#2303)
  * fix typo. (#2307)
* Thu Oct  6 2022 kastl@b1-systems.de
- Update to version 0.39.1:
  * #2222 Terragrunt sub-commands help output (#2297)
  * [skip ci] Update CODEOWNERS (#2296)
* Fri Sep 30 2022 kastl@b1-systems.de
- Update to version 0.39.0:
  * #2259 Improve handling of failures in outputs reading (#2288)
  * Docs: update to mention run-all commands not xxx-all (#2266)
* Thu Sep 15 2022 kastl@b1-systems.de
- Update to version 0.38.12:
  * Adds retryable error regex to match rate limit message from CodeCommit (#2276)
* Thu Sep 15 2022 kastl@b1-systems.de
- Update to version 0.38.11:
  * Uses partition from session when constructing the KMS Key ARN (#2257)
* Tue Sep 13 2022 kastl@b1-systems.de
- Update to version 0.38.10:
  * Share `Env` attributes with `cfgOptions`. (#2274)
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.38.9:
  * Improve partial parsing HCL strings by adding cache (#2204)
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.38.8:
  * #2245: Add option to skip state bucket public access blocking (#2246)
  * fix(docs): use correct link (#2250)
  * Update render json tests to use different directories and avoid parallel execution errors (#2248)
  * fix(docs): correct spelling (#2238)
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.38.7:
  * Fix bug where terragrunt run-all render-json overwrites all files (#2230)
  * Remove commercial-support page and references (#2197)
  * Fix typo (#2213)
* Fri Jul 22 2022 kastl@b1-systems.de
- Update to version 0.38.6:
  * Add metadata to render-json output (#2199)
  * Remove unused appveyor (#2194)
* Sat Jul 16 2022 kastl@b1-systems.de
- Update to version 0.38.5:
  * Improve Terragrunt error logs (#2175)
  * Fix bug in render-json with dependency and locals (#2191)
  * Addresses dependabot alerts (#2192)
  * Bump nokogiri from 1.12.5 to 1.13.6 in /docs (#2115)
  * Fix quick-start typo (#2183)
  * Fix typo (#2186)
  * Set compatibilty version to go 1.17 (#2180)
  * Update codeowners (#2162)
* Tue Jul  5 2022 kastl@b1-systems.de
- Update to version 0.38.4:
  * Use faster hashing approach when handling local module sources (#2168)
* Fri Jul  1 2022 kastl@b1-systems.de
- Update to version 0.38.3:
  * #2113 Improved parsing of AWS policy response (#2118)
  * #2109  Updated reading of AWS response using BoolValue function (#2111)
  * Integration tests stability (#2160)
* Tue Jun 28 2022 kastl@b1-systems.de
- Update to version 0.38.2:
  * #2045 Fixed pattern matching for error hooks  (#2101)
* Wed Jun 22 2022 kastl@b1-systems.de
- Update to version 0.38.1:
  * feat: fetch dependency output from state (#2123)
  * Add ability to customize SSE settings for the remote state bucket (#2157)
  * Add ability to disable auto-approve (#2156)
* Wed Jun 22 2022 kastl@b1-systems.de
- Update to version 0.38.0:
  * Test against terraform 1.2 (#2147)
* Wed Jun 22 2022 kastl@b1-systems.de
- Update to version 0.37.4:
  * Make include_in_copy work for patterns containing parent folders (#2112)
* Wed Jun 22 2022 kastl@b1-systems.de
- Update to version 0.37.3:
  * feat: improve local source code download behaviour (#2006)
* Thu Jun  9 2022 kastl@b1-systems.de
- Update to version 0.37.2:
  * Bump github.com/hashicorp/go-getter from 1.5.11 to 1.6.1 (#2131)
  * Check in Pull Request template (#2124)
* Sat May 14 2022 kastl@b1-systems.de
- Update to version 0.37.1:
  * Update remote state docs to recommend generate first (#2106)
* Sat May 14 2022 kastl@b1-systems.de
- Update to version 0.37.0:
  * fix config remote state s3 and update if needs (#2063)
* Fri May 13 2022 kastl@b1-systems.de
- Update to version 0.36.12:
  * Allow v0.36 to define disable_bucket_update to make it easier to transition to v0.37 (#2105)
* Fri May 13 2022 kastl@b1-systems.de
- Update to version 0.36.11:
  * Bump github.com/hashicorp/go-getter from 1.5.7 to 1.5.11 (#2095)
* Thu May  5 2022 kastl@b1-systems.de
- Update to version 0.36.10:
  * fix bug where strict validation wasn't always respected (#2056)
  * fix(docs): missing cli options on the summary (#2088)
* Sat Apr 30 2022 kastl@b1-systems.de
- Update to version 0.36.9:
  * git_functions: propegate the opts.Env for git commands (#2086)
  * Fix get_path_from_repo_root typo (#2035)
* Thu Apr 28 2022 kastl@b1-systems.de
- Update to version 0.36.8:
  * Bump sops from v3.7.0 to v3.7.2 (#2083)
  * Failing tests fixes (#2073)
  * Clarify behavior of terragrunt-tfpath override with respect to dependencies (#2077)
* Sat Apr 16 2022 kastl@b1-systems.de
- Update to version 0.36.7:
  * Additional known transient error handling (#2066)
  * Update inputs.md (#2053)
* Fri Mar 18 2022 kastl@b1-systems.de
- Update to version 0.36.6:
  * fix: use correct slashes for repo root functions (#2042)
* Wed Mar 16 2022 kastl@b1-systems.de
- Update to version 0.36.5:
  * Enable public access blocking for access logs S3 bucket as well, if configured (#2040)
* Wed Mar 16 2022 kastl@b1-systems.de
- Update to version 0.36.4:
  * #1971 Added caching of IAM roles parsed from HCL files (#2010)
  * Removed empty list item (#2030)
* Thu Mar  3 2022 kastl@b1-systems.de
- Update to version 0.36.3:
  * Add get_repo_root() built-in (#2027)
* Thu Mar  3 2022 kastl@b1-systems.de
- Update to version 0.36.2:
  * Add merge strategies for mock outputs with state (#1936)
  * Update cli-options.md to mention silent auto-approve on run-all. (#1992)
* Tue Feb  1 2022 kastl@b1-systems.de
- Update to version 0.36.1:
  * Handle relative paths correctly when fetching tfr (#2005)
  * CI Build fix (#2001)
  * Add 1.1.x to version compatibility table (#1991)
* Wed Jan 26 2022 Johannes Kastl <kastl@b1-systems.de>
- new package terragrunt at version 0.36.0
